@@ -32,12 +32,33 @@
 #' Currently, we can only estimate the difference in RMST for a single binary
 #' exposure. Two separate Cox models are fit for each level of the exposure,
 #' which is expected to be coded as 0/1.
-#' @return An object of class \code{std_surv}.
-#' This is basically a list with components estimates and covariance estimates in \code{res}
-#' Results for transformations, contrasts, references are stored in \code{res_contrasts}.
-#' The output contains estimates for contrasts and confidence intervals for all
-#' combinations of transforms and reference levels.
-#' Obtain numeric results in a data frame with the \link{tidy} function.
+#' @return An object of class \code{std_surv}. Obtain numeric results by using \link{tidy.std_surv}.
+#' This is a list with the following components:
+#' \describe{
+#'  \item{res_contrast}{An unnamed list with one element for each of the requested contrasts. Each element is itself a list with the elements:
+#'  \describe{
+#'  \item{call}{The function call}
+#'  \item{input}{A list with components used in the estimation}
+#'  \item{measure}{Either "survival" or "rmean"}
+#'  \item{est}{Estimated counterfactual means and standard errors for each exposure level}
+#'  \item{vcov}{Estimated covariance matrix of counterfactual means for each time}
+#'  \item{est_table}{Data.frame of the estimates of the contrast with inference}
+#'  \item{times}{The vector of times used in the calculation}
+#'  \item{transform}{The transform argument used for this contrast}
+#'  \item{contrast}{The requested contrast type}
+#'  \item{reference}{The reference level of the exposure}
+#'  \item{ci_type}{Confidence interval type}
+#'  \item{ci_level}{Confidence interval level}
+#' }}
+#' \item{res}{A named list with the elements:
+#'  \describe{
+#'  \item{call}{The function call}
+#'  \item{input}{A list with components used in the estimation}
+#'  \item{measure}{Either "survival" or "rmean"}
+#'  \item{est}{Estimated counterfactual means and standard errors for each exposure level}
+#'  \item{vcov}{Estimated covariance matrix of counterfactual means for each time}
+#' }
+#' }}
 #' @inherit standardize_glm
 #' @param times A vector containing the specific values of \eqn{T} at
 #' which to estimate the standardized survival function.
@@ -162,7 +183,7 @@ standardize_coxph <- function(formula,
 
     ## Check that exposure is binary
     if (!is.binary(data[[names(values)]]) || nrow(valuesout) != 2L) {
-      stop("the exposure has to be binary (0 or 1)")
+      stop("the exposure has to be binary and coded as 0, 1. It is currently ", class(data[[names(values)]]))
     }
 
     #---PREPARATION---
@@ -503,8 +524,8 @@ standardize_coxph <- function(formula,
         # Note: need to center at factual X, not counterfactual x,
         # since baseline is computed at mean of factual X.
         m.x <- model.matrix(object = terms(fit), data = data.x)[, -1, drop = FALSE]
-        m <- model.matrix(object = terms(fit), data = data)[, -1, drop = FALSE]
-        m <- matrix(colMeans(m), nrow = nrow(m), ncol = ncol(m), byrow = TRUE)
+        #m <- model.matrix(object = terms(fit), data = data)[, -1, drop = FALSE]
+        m <- matrix(fit$means, nrow = nrow(m), ncol = ncol(m), byrow = TRUE)
         m.x <- m.x - m
         tempmat[i, ] <- colMeans(m.x * predX * si[, i] * weights)
       }
